from papermage.recipes.core_recipe import CoreRecipe
from papermage.recipes.minimal_pdf_recipe import (
    MinimalTextImageRecipe,
    MinimalTextOnlyRecipe,
)
from papermage.recipes.text_recipe import TextRecipe

__all__ = ["CoreRecipe", "TextRecipe", "MinimalTextImageRecipe", "MinimalTextOnlyRecipe"]
